# frozen_string_literal: true

class QueueBackfillVulnerabilityFindingsRemediationsProjectId < Gitlab::Database::Migration[2.2]
  milestone '17.2'
  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell

  MIGRATION = "BackfillVulnerabilityFindingsRemediationsProjectId"
  DELAY_INTERVAL = 2.minutes
  BATCH_SIZE = 1000
  SUB_BATCH_SIZE = 100

  def up
    Gitlab::Database::QueryAnalyzers::Base.suppress_schema_issues_for_decomposed_tables do
      queue_batched_background_migration(
        MIGRATION,
        :vulnerability_findings_remediations,
        :id,
        :project_id,
        :vulnerability_occurrences,
        :project_id,
        :vulnerability_occurrence_id,
        job_interval: DELAY_INTERVAL,
        batch_size: BATCH_SIZE,
        sub_batch_size: SUB_BATCH_SIZE
      )
    end
  end

  def down
    Gitlab::Database::QueryAnalyzers::Base.suppress_schema_issues_for_decomposed_tables do
      delete_batched_background_migration(
        MIGRATION,
        :vulnerability_findings_remediations,
        :id,
        [
          :project_id,
          :vulnerability_occurrences,
          :project_id,
          :vulnerability_occurrence_id
        ]
      )
    end
  end
end
